# freezy
- Calculate mouse speed using DLC coordinates.
- Automatic trace smoothing through '[savitzky golay](https://en.wikipedia.org/wiki/Savitzky%E2%80%93Golay_filter)' filter.

# How to use
```console
pip install freezy
```

# Examples
- Refer 'examples' directory.

![Result](./examples/result_examples_motion.png)  